package it.tecnologieweb.pizza.web.beans;

import it.tecnologieweb.pizza.web.dao.CorsoDAO;
import it.tecnologieweb.pizza.web.dao.CorsoTO;
import it.tecnologieweb.pizza.web.dao.DAOFactory;
import it.tecnologieweb.pizza.web.dao.ProfessoreDAO;
import it.tecnologieweb.pizza.web.dao.ProfessoreTO;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;

import javax.faces.component.html.HtmlDataTable;
import javax.faces.model.SelectItem;

public class Manager {

	// --------------------------------------------------------------------
	// --- variabili statiche per rappresentare le azioni di navigazione --
	// --------------------------------------------------------------------

	private static final String listaProfessori = "listaProfessori";
	private static final String vediProfessore = "vediProfessore";
	private static final String addProfessore = "addProfessore";
	private static final String modProfessore = "modProfessore";

	private static final String vediCorso = "vediCorso";
	private static final String listaCorsi = "lsitaCorsi";
	private static final String addCorso = "addCorso";


	// -----------------------------------------------------------
	// --- variabili membro di utilita interna  ------------------
	// -----------------------------------------------------------

	private DAOFactory dao_factory = DAOFactory.getDAOFactory(DAOFactory.HSQLDB);

	// -----------------------------------------------------------
	// --- data and accessor methods -----------------------------
	// -----------------------------------------------------------

	private ArrayList professori;
	public ArrayList getProfessori() {
		ProfessoreDAO p_dao = dao_factory.getProfessoreDAO();
		professori = (ArrayList) p_dao.getProfessori();
		return professori;
	}
	public void setProfessori(ArrayList professori) {
		this.professori = professori;
	}

	private HtmlDataTable dataProfessori;
	public HtmlDataTable getDataProfessori() {
		return dataProfessori;
	}
	public void setDataProfessori(HtmlDataTable dataProfessori) {
		this.dataProfessori = dataProfessori;
	}

	// -----------------------------------------------------------

	private ProfessoreTO professore;
	public ProfessoreTO getProfessore() {
		if (professore == null)
			professore = new ProfessoreTO();
		return professore;
	}
	public void setProfessore(ProfessoreTO professore) {
		this.professore = professore;
	}

	// -----------------------------------------------------------

	private ArrayList corsi;
	public ArrayList getCorsi() {
		CorsoDAO c_dao = dao_factory.getCorsoDAO();
		corsi = (ArrayList) c_dao.getCorsi();
		return corsi;
	}
	public void setCorsi(ArrayList corsi) {
		this.corsi = corsi;
	}

	private HtmlDataTable dataCorsi;
	public HtmlDataTable getDataCorsi() {
		return dataCorsi;
	}
	public void setDataCorsi(HtmlDataTable dataCorsi) {
		this.dataCorsi = dataCorsi;
	}

	// -----------------------------------------------------------

	private CorsoTO corso;
	public CorsoTO getCorso() {
		if (corso == null)
			corso = new CorsoTO();
		return corso;
	}
	public void setCorso(CorsoTO corso) {
		this.corso = corso;
	}

	// -----------------------------------------------------------
	// --- biz logic e navigazione -----------------------------
	// -----------------------------------------------------------

	public String addNewProf() {
		this.professore = new ProfessoreTO();
		return addProfessore;
	}

	public String creaProfessore() {
		this.insertProfTO();
		return vediProfessore;
	}

	public String updateProfessore() {
		this.updateProfTO();
		return vediProfessore;
	}

	public String deleteProfessore() {
		this.deleteProfTO();
		return listaProfessori;
	}

	public String vediProfessore() {
		this.readProfTO_from_selected_RowData();
		return vediProfessore;
	}

	public String modificaProfessore() {
		this.readProfTO_from_selected_RowData();
		return modProfessore;
	}

	public String addNewCorso() {
		this.corso = new CorsoTO();
		return addCorso;
	}

	public String loggaProfessore() {
		System.out.println( "You have selected: " +	
			((ProfessoreTO)this.dataProfessori.getRowData()).
				getMatricola() );
		return null;
	}
	
	// -----------------------------------------------------------

	public String creaCorso() {
		this.insertCorsoTO();
		return vediCorso;
	}

	public String vediCorso() {
		this.readCorsoTO_from_selected_RowData();
		return vediCorso;
	}

	public String eliminaCorso() {
		this.deleteCorsoTO_from_selected_RowData();
		return listaCorsi;
	}

	// ----------------------------------------------------------------
	// --- metodi di utilit? per i componenti UI ----------------------
	// ----------------------------------------------------------------
	
	public SelectItem[] getProfessoriList() {
		ProfessoreDAO p_dao = dao_factory.getProfessoreDAO();
		professori = (ArrayList) p_dao.getProfessori();
		SelectItem[] profList = new SelectItem[professori.size()];
		int i = 0;
		for (Iterator iter = professori.iterator(); iter.hasNext();) {
			ProfessoreTO p = (ProfessoreTO) iter.next();
			profList[i] = new SelectItem(p.getId(), p.getCognome() + " "
					+ p.getNome());
			i++;
		}
		return profList;
	}
	
	// --------------------------------------------------------------------
	// --- metodi per l'accesso e la modifica a/di dati persistenti -------
	// --------------------------------------------------------------------

	private void insertProfTO() {
		ProfessoreDAO p_dao = dao_factory.getProfessoreDAO();
		if (this.professore.getFoto() != null) {
			System.out.println("********************");
			System.out.println("tipo: "
					+ this.professore.getFoto().getContentType());
			System.out.println("tipo: "
					+ this.professore.getFoto().getName());
			System.out.println("********************");
			try {
				this.professore.setFotoBytes(this.professore.getFoto()
						.getBytes());
				this.professore.setFotoContentType(this.professore
						.getFoto().getContentType());
				this.professore.setFotoName(this.professore.getFoto()
						.getName());
			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
		int id = p_dao.insertProfessore(this.professore);
		if (id != 0)
			this.professore.setId(id);
	}

	private void updateProfTO() {
		ProfessoreDAO p_dao = dao_factory.getProfessoreDAO();
		if (this.professore.getFoto() != null) {
			System.out.println("********************");
			System.out.println("tipo: "
					+ this.professore.getFoto().getContentType());
			System.out.println("tipo: "
					+ this.professore.getFoto().getName());
			System.out.println("********************");
			try {
				this.professore.setFotoBytes(this.professore.getFoto()
						.getBytes());
				this.professore.setFotoContentType(this.professore
						.getFoto().getContentType());
				this.professore.setFotoName(this.professore.getFoto()
						.getName());
			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
		p_dao.updateProfessore(this.professore);
	}

	private void deleteProfTO() {
		ProfessoreDAO p_dao = dao_factory.getProfessoreDAO();
		p_dao.delProfessore(this.professore.getId());
	}

	private void readProfTO_from_selected_RowData() {
		this.professore = (ProfessoreTO) this.dataProfessori.getRowData();
		ProfessoreDAO p_dao = dao_factory.getProfessoreDAO();
		// retrieves full features from the database (i.e. teachings!!!)
		this.professore = p_dao.getProfessore(this.professore.getId());
	}

	// -----------------------------------------------------------

	private void insertCorsoTO() {
		CorsoDAO c_dao = dao_factory.getCorsoDAO();
		ProfessoreDAO p_dao = dao_factory.getProfessoreDAO();
		ProfessoreTO prof = p_dao.getProfessore(this.corso.getIdProf());
		this.corso.setProfessore(prof);
		int id = c_dao.insertCorso(this.corso);
		if (id != 0)
			this.corso.setId(id);
	}

	private void readCorsoTO_from_selected_RowData() {
		this.corso = (CorsoTO) this.dataCorsi.getRowData();
		CorsoDAO c_dao = dao_factory.getCorsoDAO();
		// retrieves full features from the database
		this.corso = c_dao.getCorso(this.corso.getId());
	}

	private void deleteCorsoTO_from_selected_RowData() {
		this.corso = (CorsoTO) this.dataCorsi.getRowData();
		CorsoDAO c_dao = dao_factory.getCorsoDAO();
		// retrieves full features from the database
		c_dao.delCorso(this.corso.getId());
		this.corso = new CorsoTO();
	}

}