package it.tecnologieweb.pizza.web.dao.hsqldb;

import it.tecnologieweb.pizza.web.dao.CorsoDAO;
import it.tecnologieweb.pizza.web.dao.DAOFactory;
import it.tecnologieweb.pizza.web.dao.ProfessoreDAO;

import java.sql.Connection;
import java.sql.DriverManager;

public class HsqldbDAOFactory 
extends DAOFactory {

	public static final String DRIVER = "org.hsqldb.jdbcDriver";
	public static final String DBURL = "jdbc:hsqldb:hsql://localhost/xdb";

	// --------------------------------------------

	public HsqldbDAOFactory() {
		try {
			Class.forName(DRIVER);
		} 
		catch (Exception e) {
			System.out.println(""+HsqldbDAOFactory.class.getSimpleName()+": failed to load HSQLDB JDBC driver" + e.toString());
			return;
		}
	}

	// --------------------------------------------
	
	public static Connection createConnection() {
		try {
			return DriverManager.getConnection(DBURL);
		} 
		catch (Exception e) {
			System.out.println(""+HsqldbDAOFactory.class.getSimpleName()+": failed to create db connection" + e.toString());
			return null;
		}
	}
	
	public static void closeConnection(Connection conn) {
		try {
			conn.close();
		}
		catch (Exception e) {
			System.out.println(""+HsqldbDAOFactory.class.getSimpleName()+": failed to close db connection" + e.toString());
		}
	}

	// --------------------------------------------
	
	@Override
	public CorsoDAO getCorsoDAO() {
		return new HsqldbCorsoDAO();
	}

	@Override
	public ProfessoreDAO getProfessoreDAO() {
		return new HsqldbProfessoreDAO();
	}

}
